/*******************************************************************************
* File Name: main.c
*
* Version: 1.0
*
* Description:
*  This project demonstrates simultaneous usage of the BLE GAP Peripheral and
*  Broadcaster roles. The device would connect to a peer device, while also
*  broadcasting (non-connectable advertising) at the same time.
*
* Hardware Dependency:
*  CY8CKIT-042-BLE Bluetooth Low Energy Pioneer Kit
*

=========================================================================================================================================================
Cypress External Response:39/13/2019 9:50 AM - P Yugandhar
Hello Luigi,

Sorry for the delayed response.

1. Please refer to the attached project.
   In the project, I configured the BLE as both central and peripheral and in the stack on event I'm starting the advertisement and scanning at the same time.
   In the event CYBLE_EVT_GAPC_SCAN_PROGRESS_RESULT, we can view all the nearby advertising devices.

2. You can add a switch button for switching the role of the device(either to advertising or scanning) on every switch interrupt.
   You can check the current state of the device using the CyBle_GetState() API function and can switch accordingly.

3. The project is configured with low power solution in which between every advertising or connection interval the device enters into the Deepsleep mode
   and the BLESS interrupt will wakes up the system from DeepSleep before start of every connection or advertisement event.
   Please refer to the below Datasheet link for more information on low power design of PSoC 4/PRoC BLE.
   Link: https://www.cypress.com/documentation/application-notes/an92584-designing-low-power-and-estimating-battery-life-ble

Please let me know if you have any questions.

Thanks,
P Yugandhar.
=========================================================================================================================================================


/*******************************************************************************
* Included headers
*******************************************************************************/

#define __MAIN_H

#include <project.h>
#include <stdlib.h>
#include <stdio.h>
#include <typedef.h>
#include <common.h>
#include <bufcir.h>
#include <timer.h>
#include <rout.h>
#include <main.h>


//#define 	HEADER_2BYTES



extern CY_ISR(U2Irq);
extern CY_ISR(Timer2mS5);


/***************************************
*        Function Prototypes
***************************************/
void StackEventHandler(uint32 event, void* eventParam);



/*******************************************************************************
* Function Name: StackEventHandler
********************************************************************************
*
* Summary:
*  This is an event callback function to receive events from the CYBLE Component.
*
* Parameters:
*  uint8 event:       Event from the CYBLE component.
*  void* eventParams: A structure instance for corresponding event type. The
*                     list of event structure is described in the component
*                     datasheet.
*
* Return:
*  None
*
*******************************************************************************/
void StackEventHandler(uint32 event, void* eventParam)
{
    /*local variables*/
   CYBLE_GAPC_ADV_REPORT_T advReport;
//   uint8 show =0;
	CYBLE_GATTS_WRITE_REQ_PARAM_T       *wrReqParam;
	CYBLE_GATTS_CHAR_VAL_READ_REQ_T     *rdReqParam;
    CYBLE_GATT_ERR_CODE_T               errore;
	char answerRequest =0;


    switch(event)
    {

        case CYBLE_EVT_STACK_ON:    /*BLE stack ON*/

                printf("\r\n-------------------------------\r\n\r\n");
                printf("BLE_ON\r\n");
                //
                // In the project, I configured the BLE as both central and peripheral.
                //
                // In the stack on event (here) I'm starting the advertisement and scanning at the same time.
                // In the event CYBLE_EVT_GAPC_SCAN_PROGRESS_RESULT, we can view all the nearby advertising devices

                // You can add a switch button for switching the role of the device(either to advertising or scanning) on every switch interrupt.
                // You can check the current state of the device using the CyBle_GetState() API function and can switch accordingly.
                //
                // The project is configured with low power solution in which between every advertising or connection interval the device enters into the Deepsleep mode
                // and the BLESS interrupt will wake up the system from DeepSleep before start of every connection or advertisement event.
                // Please refer to the below Datasheet link for more information on low power design of PSoC 4/PRoC BLE.
                // Link: https://www.cypress.com/documentation/application-notes/an92584-designing-low-power-and-estimating-battery-life-ble
                //
                cyBle_discoveryInfo.discProcedure=CYBLE_GAPC_GEN_DISC_PROCEDURE;
                CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST);
                CyBle_GapcStartDiscovery(&cyBle_discoveryInfo);
            break;

        case CYBLE_EVT_STACK_BUSY_STATUS:
            printf("(STACK_BUSY)\n");
            break;

        case CYBLE_EVT_TIMEOUT: /* 0x01 -> GAP limited discoverable mode timeout. */
                                /* 0x02 -> GAP pairing process timeout. */
                                /* 0x03 -> GATT response timeout. */
            printf("(EVT_TOUT: %d)\n", *(uint8 *)eventParam);
            break;

        case CYBLE_EVT_HARDWARE_ERROR:    /* This event indicates that some internal HW error has occurred. */
            printf("(HARDWARE_ERROR)\n");
            break;

        case CYBLE_EVT_HCI_STATUS:
            printf("(HCI_STATUS)\n");
            break;


        case CYBLE_EVT_GAPC_SCAN_PROGRESS_RESULT:

                /* scan progress result event occurs
                 * when it receives any advertisiment packet
                 * or scan response packet from peer device*/

                advReport=*(CYBLE_GAPC_ADV_REPORT_T *)eventParam;

                switch(advReport.eventType)  // (_GG_) enum CYBLE_GAPC_ADV_EVENT_T
                {
                    case CYBLE_GAPC_CONN_UNDIRECTED_ADV:
                        //_GG_ printf("Connectable undirected advertising\r\n");
                        break;
                    case  CYBLE_GAPC_CONN_DIRECTED_ADV:
                        //_GG_ printf("Connectable directed advertising\r\n");
                        break;
                    case  CYBLE_GAPC_SCAN_UNDIRECTED_ADV:
                        //_GG_ printf("Scannable undirected advertising\r\n");
                        break;

                    case CYBLE_GAPC_NON_CONN_UNDIRECTED_ADV:
                        //
                        // (_GG_) Broadcast Packed Received
                        //
                        if(advReport.peerAddrType==CYBLE_GAP_ADDR_TYPE_PUBLIC)
                        {
                             /*  NCU: NonConnectableUndirect */
                            printf("%05d NCU:%2.2X%2.2X%2.2X%2.2X%2.2X%2.2X\r\n",
                                millisecCtr,
                                advReport.peerBdAddr[5u], advReport.peerBdAddr[4u],
                                advReport.peerBdAddr[3u], advReport.peerBdAddr[2u],
                                advReport.peerBdAddr[1u], advReport.peerBdAddr[0u]);

                            /*  RSSI of the received packet from peer Device  */
                            printf("RSSI:%04d\r\n", advReport.rssi);
                        }
                        break;

                    case CYBLE_GAPC_SCAN_RSP:
                        //
                        //  _GG_ BLE_GAPC_SCAN_RSP Scan Response
                        //
                        // printf("SCAN_RSP\r\n");
                        break;
                }
            break;

         case  CYBLE_EVT_GAPC_SCAN_START_STOP:
                if(CyBle_GetState()==CYBLE_STATE_DISCONNECTED)
                {   /*Restart scanning if time out happens*/
                    CyBle_GapcStartScan(CYBLE_SCANNING_SLOW);
                }
            break;


        /**********************************************************
        *                       GAP Events
        ***********************************************************/

		 case CYBLE_EVT_GAP_DEVICE_CONNECTED:
                printf("\r\n DevConnected");
            break;

        case CYBLE_EVT_GAP_AUTH_REQ:
            printf("(GAP_AUTH_REQ)\n");
            break;

        case CYBLE_EVT_GAP_AUTH_FAILED:
            printf("GAP_AUTH_FAILED, reason: ");
            switch(*(CYBLE_GAP_AUTH_FAILED_REASON_T *)eventParam)
            {
                case CYBLE_GAP_AUTH_ERROR_CONFIRM_VALUE_NOT_MATCH:
                    printf("CONFIRM_VALUE_NOT_MATCH\r\n");
                    break;

                case CYBLE_GAP_AUTH_ERROR_INSUFFICIENT_ENCRYPTION_KEY_SIZE:
                    printf("INSUFFICIENT_ENCRYPTION_KEY_SIZE\r\n");
                    break;

                case CYBLE_GAP_AUTH_ERROR_UNSPECIFIED_REASON:
                    printf("UNSPECIFIED_REASON\r\n");
                    break;

                case CYBLE_GAP_AUTH_ERROR_AUTHENTICATION_TIMEOUT:
                    printf("AUTHENTICATION_TIMEOUT\r\n");
                    break;

                default:
                    printf("0x%x  \r\n", *(CYBLE_GAP_AUTH_FAILED_REASON_T *)eventParam);
                    break;
            }
            break;


        case CYBLE_EVT_GAPC_CONNECTION_UPDATE_COMPLETE:
            printf("(GAPC_CONN_UPDATE_COMPLETE)\n");
            break;

        case CYBLE_EVT_GAP_DEVICE_DISCONNECTED:
            printf("(GAP_DEVICE_DISCONNECTED, reason: %x)\n", *(uint8*)eventParam);
            /* Put the device into discoverable mode so that remote can search it. */
    		bleActive =0;

            if(CyBle_GetState()==CYBLE_STATE_DISCONNECTED)
            {   // _GG_
                CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST);
            }
            break;

//        case CYBLE_EVT_GAP_AUTH_COMPLETE:
//            DBG_PRINTF("CYBLE_EVT_GAP_AUTH_COMPLETE: security:%x, bonding:%x, ekeySize:%x, authErr %x \r\n",
//                        ((CYBLE_GAP_AUTH_INFO_T *)eventParam)->security,
//                        ((CYBLE_GAP_AUTH_INFO_T *)eventParam)->bonding,
//                        ((CYBLE_GAP_AUTH_INFO_T *)eventParam)->ekeySize,
//                        ((CYBLE_GAP_AUTH_INFO_T *)eventParam)->authErr);
//            break;

//        case CYBLE_EVT_GAP_ENCRYPT_CHANGE:
//            DebugPrintInt("CYBLE_EVT_GAP_ENCRYPT_CHANGE: %d \r\n", *(uint8 *)eventParam);
//            break;

        case CYBLE_EVT_GAPP_ADVERTISEMENT_START_STOP:
//            DebugPrintInt("CYBLE_EVT_GAPP_ADVERTISEMENT_START_STOP, state: %x\r\n", CyBle_GetState());
//            PrintState();

//            if(CYBLE_STATE_DISCONNECTED == CyBle_GetState())
//            {
//                /* Fast and slow advertising period complete, go to low power
//                 * mode (Hibernate mode) and wait for an external
//                 * user event to wake up the device again */
//                DebugPrint("Hibernate \r\n");
//            #if (DEBUG_UART_ENABLED == ENABLED)
//                while((UART_DEB_SpiUartGetTxBufferSize() + UART_DEB_GET_TX_FIFO_SR_VALID) != 0);
//            #endif /* (DEBUG_UART_ENABLED == ENABLED) */
//                CySysPmHibernate();
//            }
            break;

        /**********************************************************
        *                       GATT Events
        ***********************************************************/
        case CYBLE_EVT_GATTC_ERROR_RSP:
            printf("(GATTC_ERROR_RSP: opcode: ");
            switch(((CYBLE_GATTC_ERR_RSP_PARAM_T *)eventParam)->opCode)
            {
                case CYBLE_GATT_FIND_INFO_REQ:
                    printf("FIND_INFO_REQ)");
                    break;

                case CYBLE_GATT_READ_BY_TYPE_REQ:
                    printf("READ_BY_TYPE_REQ)");
                    break;

                case CYBLE_GATT_READ_BY_GROUP_REQ:
                    printf("READ_BY_GROUP_REQ)");
                    break;

                default:
                    printf("%x", ((CYBLE_GATTC_ERR_RSP_PARAM_T *)eventParam)->opCode);
                    break;
            }
            printf(",  handle: %x,  ", ((CYBLE_GATTC_ERR_RSP_PARAM_T *)eventParam)->attrHandle);
            printf("errorcode: ");
            switch(((CYBLE_GATTC_ERR_RSP_PARAM_T *)eventParam)->errorCode)
            {
                case CYBLE_GATT_ERR_ATTRIBUTE_NOT_FOUND:
                    printf("ATTRIBUTE_NOT_FOUND");
                    break;

                default:
                    printf("%x", ((CYBLE_GATTC_ERR_RSP_PARAM_T *)eventParam)->errorCode);
                    break;
            }
            printf("\r\n");
            break;

        case CYBLE_EVT_GATT_CONNECT_IND:
/*
            DBG_PRINTF("CYBLE_EVT_GATT_CONNECT_IND: attId %x, bdHandle %x \r\n",
                ((CYBLE_CONN_HANDLE_T *)eventParam)->attId, ((CYBLE_CONN_HANDLE_T *)eventParam)->bdHandle);   */
            printf("(GATT_CONNECT_IND)\n");
            break;

        case CYBLE_EVT_GATT_DISCONNECT_IND:
            printf("(GATT_DISCONNECT_IND)\n");
            break;

        case CYBLE_EVT_GATTS_XCNHG_MTU_REQ:
            printf("(GATTS_XCNHG_MTU_REQ)\n");
            break;

        case CYBLE_EVT_GATTS_HANDLE_VALUE_CNF:
            printf("(GATTS_HANDLE_VALUE_CNF)\n");
            break;

        case CYBLE_EVT_GATTS_READ_CHAR_VAL_ACCESS_REQ:
            /* Triggered on server side when client sends read request and when
            * characteristic has CYBLE_GATT_DB_ATTR_CHAR_VAL_RD_EVENT property set.
            * This event could be ignored by application unless it need to response
            * by error response which needs to be set in gattErrorCode field of
            * event parameter. */

			rdReqParam = (CYBLE_GATTS_CHAR_VAL_READ_REQ_T *) eventParam;
			if (rdReqParam->attrHandle  == BLE_TX_HANDLE)
			{
				clientEventReady =1;
			}

          	printf("(GATTS_RD: hndle: %x)\n", ((CYBLE_GATTS_CHAR_VAL_READ_REQ_T *)eventParam)->attrHandle);
            break;

		//==============================================================================================
		case CYBLE_EVT_GATTS_WRITE_REQ:
            answerRequest=1;
		case CYBLE_EVT_GATTS_WRITE_CMD_REQ:
			wrReqParam = (CYBLE_GATTS_WRITE_REQ_PARAM_T *) eventParam;
#if 0
			{
                uint8 tmp[32],i;

			    // DEBUG: print dati scrittura carattesistica
			    //
			    MemFill(U08PTR tmp, 0, sizeof(tmp));
			    sprintf((char *)&tmp,"WR_CH: %02X, dati:", wrReqParam->handleValPair.attrHandle);  //
				printf((char *)tmp);

				for (i=0; i<wrReqParam->handleValPair.value.len ; i++ )
				{
			    	sprintf((char *)&tmp,"[%02X]", wrReqParam->handleValPair.value.val[(u08)i]);  //
					printf((char *)tmp);
				}
				printf("\n");
			}
#endif
            if(wrReqParam->handleValPair.attrHandle == BLE_RX_HANDLE)
            {
  				clientEventReady =1;    // se era appeso A "0"

                /* Store BLE_RX_HANDLE Characteristic data in local array */
    	        errore = CyBle_GattsWriteAttributeValue(&wrReqParam->handleValPair, 0, &cyBle_connHandle, 0);
                if (errore) errore |=0;  // compiler warning bypass

                BufCirStrCopy((STRUCT_BUFCIR *)&comm.buffCircRx, wrReqParam->handleValPair.value.val, wrReqParam->handleValPair.value.len);
				if (answerRequest)                	CyBle_GattsWriteRsp(cyBle_connHandle);  // Send the response to the write request.
            }
            if(wrReqParam->handleValPair.attrHandle == 0x28)
            {
            }
            break;
		//==============================================================================================

        /**********************************************************
        *                       L2CAP Events
        ***********************************************************/

        case CYBLE_EVT_L2CAP_CONN_PARAM_UPDATE_REQ:
            printf ("(L2CAP_CONN_PARAM_UPDATE_REQ)\n");
            break;

        /**********************************************************
        *                       Other Events
        ***********************************************************/
        case CYBLE_EVT_PENDING_FLASH_WRITE:
            /* Inform application that flash write is pending. Stack internal data
            * structures are modified and require to be stored in Flash using
            * CyBle_StoreBondingData() */
            printf("(PENDING_FLASH_WRITE)\n");
            break;

        default:
            printf("Other event: 0x%lx \r\n", event);
            break;

    }
}

//================================================================================================
void InitializeSystem(void)
//================================================================================================
{
       /* Start communication component */
    UART_Start();

    /* Enable global interrupts */
    CyGlobalIntEnable;

    /* Internal low power oscillator is stopped as it is not used in this project */
    CySysClkIloStop();

    /* Set the divider for ECO, ECO will be used as source when IMO is switched off to save power,
    **  to drive the HFCLK */
    CySysClkWriteEcoDiv(CY_SYS_CLK_ECO_DIV8);

    CyBle_Start(StackEventHandler);

    Timer1_Start();
    TimerIrq_StartEx(Timer2mS5);
	millisecCtr = 0;
}

/*******************************************************************************
* Function Name: main
********************************************************************************
*
* Summary:
*  Main function.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/

int main()
{

    /* Variable declarations */
    CYBLE_LP_MODE_T lpMode;
    CYBLE_BLESS_STATE_T blessState;
    uint8 InterruptsStatus;


    InitializeSystem();

    bleActive=0;
//	goodPwd =0;
//	debuggedYet =0;
//    sendPr.debugNotify =0;
//	easyError = U08PTR "noError";

    /*Infinite Loop*/
    for(;;)
    {

        if((UART_SpiUartGetTxBufferSize() + UART_GET_TX_FIFO_SR_VALID) == 0)
        {

           if(CyBle_GetState() != CYBLE_STATE_INITIALIZING)
           {
                /* Put BLE sub system in DeepSleep mode when it is idle */
                 lpMode = CyBle_EnterLPM(CYBLE_BLESS_DEEPSLEEP);

               /* Disable global interrupts to avoid any other tasks from interrupting this section of code*/
                InterruptsStatus = CyEnterCriticalSection();

                /* Get current state of BLE sub system to check if it has successfully entered deep sleep state */
                blessState = CyBle_GetBleSsState();

                /* If BLE sub system has entered deep sleep, put chip into deep sleep for reducing power consumption */
                if(lpMode == CYBLE_BLESS_DEEPSLEEP)
                {
                    if(blessState == CYBLE_BLESS_STATE_ECO_ON || blessState == CYBLE_BLESS_STATE_DEEPSLEEP)
                    {
                       /* Put the chip into the deep sleep state as there are no pending tasks and BLE has also
                       ** successfully entered BLE DEEP SLEEP mode */
                       CySysPmDeepSleep();
                    }
                }

                /* BLE sub system has not entered deep sleep, wait for completion of radio operations */
                else if(blessState != CYBLE_BLESS_STATE_EVENT_CLOSE)
                {

                    /* change HF clock source from IMO to ECO, as IMO can be stopped to save power */
                    CySysClkWriteHfclkDirect(CY_SYS_CLK_HFCLK_ECO);
                    /* stop IMO for reducing power consumption */
                    CySysClkImoStop();
                    /* put the CPU to sleep */
                    CySysPmSleep();
                    /* starts execution after waking up, start IMO */
                    CySysClkImoStart();
                    /* change HF clock source back to IMO */
                    CySysClkWriteHfclkDirect(CY_SYS_CLK_HFCLK_IMO);

                }

                /*Enable interrupts */
                CyExitCriticalSection(InterruptsStatus);

            }/*end of if(CyBle_GetState() != CYBLE_STATE_INITIALIZING)*/

            CyBle_ProcessEvents();

        }

    }

 }


/* [] END OF FILE */

