/***************************************************************************//**
* \file UART2_BOOT.h
* \version 4.0
*
* \brief
*  This file provides constants and parameter values of the bootloader
*  communication APIs for the SCB Component.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2014-2017, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_BOOT_UART2_H)
#define CY_SCB_BOOT_UART2_H

#include "UART2_PVT.h"

#if (UART2_SCB_MODE_I2C_INC)
    #include "UART2_I2C.h"
#endif /* (UART2_SCB_MODE_I2C_INC) */

#if (UART2_SCB_MODE_EZI2C_INC)
    #include "UART2_EZI2C.h"
#endif /* (UART2_SCB_MODE_EZI2C_INC) */

#if (UART2_SCB_MODE_SPI_INC || UART2_SCB_MODE_UART_INC)
    #include "UART2_SPI_UART.h"
#endif /* (UART2_SCB_MODE_SPI_INC || UART2_SCB_MODE_UART_INC) */


/***************************************
*  Conditional Compilation Parameters
****************************************/

/* Bootloader communication interface enable */
#define UART2_BTLDR_COMM_ENABLED ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_UART2) || \
                                             (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

/* Enable I2C bootloader communication */
#if (UART2_SCB_MODE_I2C_INC)
    #define UART2_I2C_BTLDR_COMM_ENABLED     (UART2_BTLDR_COMM_ENABLED && \
                                                            (UART2_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             UART2_I2C_SLAVE_CONST))
#else
     #define UART2_I2C_BTLDR_COMM_ENABLED    (0u)
#endif /* (UART2_SCB_MODE_I2C_INC) */

/* EZI2C does not support bootloader communication. Provide empty APIs */
#if (UART2_SCB_MODE_EZI2C_INC)
    #define UART2_EZI2C_BTLDR_COMM_ENABLED   (UART2_BTLDR_COMM_ENABLED && \
                                                         UART2_SCB_MODE_UNCONFIG_CONST_CFG)
#else
    #define UART2_EZI2C_BTLDR_COMM_ENABLED   (0u)
#endif /* (UART2_EZI2C_BTLDR_COMM_ENABLED) */

/* Enable SPI bootloader communication */
#if (UART2_SCB_MODE_SPI_INC)
    #define UART2_SPI_BTLDR_COMM_ENABLED     (UART2_BTLDR_COMM_ENABLED && \
                                                            (UART2_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             UART2_SPI_SLAVE_CONST))
#else
        #define UART2_SPI_BTLDR_COMM_ENABLED (0u)
#endif /* (UART2_SPI_BTLDR_COMM_ENABLED) */

/* Enable UART bootloader communication */
#if (UART2_SCB_MODE_UART_INC)
       #define UART2_UART_BTLDR_COMM_ENABLED    (UART2_BTLDR_COMM_ENABLED && \
                                                            (UART2_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             (UART2_UART_RX_DIRECTION && \
                                                              UART2_UART_TX_DIRECTION)))
#else
     #define UART2_UART_BTLDR_COMM_ENABLED   (0u)
#endif /* (UART2_UART_BTLDR_COMM_ENABLED) */

/* Enable bootloader communication */
#define UART2_BTLDR_COMM_MODE_ENABLED    (UART2_I2C_BTLDR_COMM_ENABLED   || \
                                                     UART2_SPI_BTLDR_COMM_ENABLED   || \
                                                     UART2_EZI2C_BTLDR_COMM_ENABLED || \
                                                     UART2_UART_BTLDR_COMM_ENABLED)


/***************************************
*        Function Prototypes
***************************************/

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (UART2_I2C_BTLDR_COMM_ENABLED)
    /* I2C Bootloader physical layer functions */
    void UART2_I2CCyBtldrCommStart(void);
    void UART2_I2CCyBtldrCommStop (void);
    void UART2_I2CCyBtldrCommReset(void);
    cystatus UART2_I2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus UART2_I2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map I2C specific bootloader communication APIs to SCB specific APIs */
    #if (UART2_SCB_MODE_I2C_CONST_CFG)
        #define UART2_CyBtldrCommStart   UART2_I2CCyBtldrCommStart
        #define UART2_CyBtldrCommStop    UART2_I2CCyBtldrCommStop
        #define UART2_CyBtldrCommReset   UART2_I2CCyBtldrCommReset
        #define UART2_CyBtldrCommRead    UART2_I2CCyBtldrCommRead
        #define UART2_CyBtldrCommWrite   UART2_I2CCyBtldrCommWrite
    #endif /* (UART2_SCB_MODE_I2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (UART2_I2C_BTLDR_COMM_ENABLED) */


#if defined(CYDEV_BOOTLOADER_IO_COMP) && (UART2_EZI2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void UART2_EzI2CCyBtldrCommStart(void);
    void UART2_EzI2CCyBtldrCommStop (void);
    void UART2_EzI2CCyBtldrCommReset(void);
    cystatus UART2_EzI2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus UART2_EzI2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map EZI2C specific bootloader communication APIs to SCB specific APIs */
    #if (UART2_SCB_MODE_EZI2C_CONST_CFG)
        #define UART2_CyBtldrCommStart   UART2_EzI2CCyBtldrCommStart
        #define UART2_CyBtldrCommStop    UART2_EzI2CCyBtldrCommStop
        #define UART2_CyBtldrCommReset   UART2_EzI2CCyBtldrCommReset
        #define UART2_CyBtldrCommRead    UART2_EzI2CCyBtldrCommRead
        #define UART2_CyBtldrCommWrite   UART2_EzI2CCyBtldrCommWrite
    #endif /* (UART2_SCB_MODE_EZI2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (UART2_EZI2C_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (UART2_SPI_BTLDR_COMM_ENABLED)
    /* SPI Bootloader physical layer functions */
    void UART2_SpiCyBtldrCommStart(void);
    void UART2_SpiCyBtldrCommStop (void);
    void UART2_SpiCyBtldrCommReset(void);
    cystatus UART2_SpiCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus UART2_SpiCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map SPI specific bootloader communication APIs to SCB specific APIs */
    #if (UART2_SCB_MODE_SPI_CONST_CFG)
        #define UART2_CyBtldrCommStart   UART2_SpiCyBtldrCommStart
        #define UART2_CyBtldrCommStop    UART2_SpiCyBtldrCommStop
        #define UART2_CyBtldrCommReset   UART2_SpiCyBtldrCommReset
        #define UART2_CyBtldrCommRead    UART2_SpiCyBtldrCommRead
        #define UART2_CyBtldrCommWrite   UART2_SpiCyBtldrCommWrite
    #endif /* (UART2_SCB_MODE_SPI_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (UART2_SPI_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (UART2_UART_BTLDR_COMM_ENABLED)
    /* UART Bootloader physical layer functions */
    void UART2_UartCyBtldrCommStart(void);
    void UART2_UartCyBtldrCommStop (void);
    void UART2_UartCyBtldrCommReset(void);
    cystatus UART2_UartCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus UART2_UartCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map UART specific bootloader communication APIs to SCB specific APIs */
    #if (UART2_SCB_MODE_UART_CONST_CFG)
        #define UART2_CyBtldrCommStart   UART2_UartCyBtldrCommStart
        #define UART2_CyBtldrCommStop    UART2_UartCyBtldrCommStop
        #define UART2_CyBtldrCommReset   UART2_UartCyBtldrCommReset
        #define UART2_CyBtldrCommRead    UART2_UartCyBtldrCommRead
        #define UART2_CyBtldrCommWrite   UART2_UartCyBtldrCommWrite
    #endif /* (UART2_SCB_MODE_UART_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (UART2_UART_BTLDR_COMM_ENABLED) */

/**
* \addtogroup group_bootloader
* @{
*/

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (UART2_BTLDR_COMM_ENABLED)
    #if (UART2_SCB_MODE_UNCONFIG_CONST_CFG)
        /* Bootloader physical layer functions */
        void UART2_CyBtldrCommStart(void);
        void UART2_CyBtldrCommStop (void);
        void UART2_CyBtldrCommReset(void);
        cystatus UART2_CyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
        cystatus UART2_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    #endif /* (UART2_SCB_MODE_UNCONFIG_CONST_CFG) */

    /* Map SCB specific bootloader communication APIs to common APIs */
    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_UART2)
        #define CyBtldrCommStart    UART2_CyBtldrCommStart
        #define CyBtldrCommStop     UART2_CyBtldrCommStop
        #define CyBtldrCommReset    UART2_CyBtldrCommReset
        #define CyBtldrCommWrite    UART2_CyBtldrCommWrite
        #define CyBtldrCommRead     UART2_CyBtldrCommRead
    #endif /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_UART2) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (UART2_BTLDR_COMM_ENABLED) */

/** @} group_bootloader */

/***************************************
*           API Constants
***************************************/

/* Timeout unit in milliseconds */
#define UART2_WAIT_1_MS  (1u)

/* Return number of bytes to copy into bootloader buffer */
#define UART2_BYTES_TO_COPY(actBufSize, bufSize) \
                            ( ((uint32)(actBufSize) < (uint32)(bufSize)) ? \
                                ((uint32) (actBufSize)) : ((uint32) (bufSize)) )

/* Size of Read/Write buffers for I2C bootloader  */
#define UART2_I2C_BTLDR_SIZEOF_READ_BUFFER   (64u)
#define UART2_I2C_BTLDR_SIZEOF_WRITE_BUFFER  (64u)

/* Byte to byte time interval: calculated basing on current component
* data rate configuration, can be defined in project if required.
*/
#ifndef UART2_SPI_BYTE_TO_BYTE
    #define UART2_SPI_BYTE_TO_BYTE   (160u)
#endif

/* Byte to byte time interval: calculated basing on current component
* baud rate configuration, can be defined in the project if required.
*/
#ifndef UART2_UART_BYTE_TO_BYTE
    #define UART2_UART_BYTE_TO_BYTE  (520u)
#endif /* UART2_UART_BYTE_TO_BYTE */

#endif /* (CY_SCB_BOOT_UART2_H) */


/* [] END OF FILE */
