/********************************************************************
* S.H.D.
* Via Bisalta 29
* 12100 - Cuneo
* Italy
*
* Item:
* Revision: 01
* Date: 16/08/2010
* Author: Alex Tardivo
* Module: bufcir.c
* Description: Gestione buffer circolari
*
*********************************************************************/
#include "typedef.h"
#include "common.h"
#include "rout.h"
#include "bufcir.h"


/*!**********************************************************
Funzione: void BufCirFlush(STRUCT_BUFCIR  *pd)
Argomenti: STRUCT_BUFCIR *pd puntatore alla tipo di struttura STRUCT_BUFCIR
Ritorno: nessuno
Descrizione: Elimina dati di un buffer circolare di tipo STRUCT_BUFCIR
**********************************************************/
void BufCirFlush(STRUCT_BUFCIR *pd)
{
    pd->put = pd->get = 0;
}

/*!**********************************************************
Funzione: void BufCirInit(STRUCT_BUFCIR  *pd, word dimMia)
Argomenti: STRUCT_BUFCIR *pd puntatore alla tipo di struttura STRUCT_BUFCIR
		   word dimMia lunghezza buffer circolare
Ritorno: nessuno
Descrizione: Inizializza un buffer circolare di tipo STRUCT_BUFCIR
**********************************************************/
void BufCirInit(STRUCT_BUFCIR  *pd, u08 *pBuf, word dimMia)
{
    pd->put = pd->get = 0;
    pd->dim = dimMia;
    pd->buf = pBuf;
    MemClear(pd->buf, dimMia);
}

/*!**********************************************************
Funzione: word BufCirFree(STRUCT_BUFCIR  *pd)
Argomenti: STRUCT_BUFCIR *pd puntatore alla tipo di struttura STRUCT_BUFCIR
Ritorno: word spazio libero
Descrizione: Valuta lo spazio disponibile di un buffer circolare di tipo STRUCT_BUFCIR
**********************************************************/
word BufCirFree(STRUCT_BUFCIR  *pd)
{
word val;
    val = (word)(pd->get - pd->put -1);
    if (pd->get <= pd->put) val += pd->dim;
    return (word)val;
}

/*!**********************************************************
Funzione: word BufCirTaken(STRUCT_BUFCIR  *pd)
Argomenti: STRUCT_BUFCIR *pd puntatore alla tipo di struttura STRUCT_BUFCIR
Ritorno: word spazio occupato
Descrizione: Valuta lo spazio occupato di un buffer circolare di tipo STRUCT_BUFCIR
**********************************************************/
word BufCirTaken(STRUCT_BUFCIR  *pd)
{
word val;
    val = (word)(pd->put - pd->get);
    if (pd->put < pd->get) val += pd->dim;
    return (word)val;
}

/*!**********************************************************
Funzione: byte BufCirDataRdy(STRUCT_BUFCIR  *pd)
Argomenti: STRUCT_BUFCIR *pd puntatore alla tipo di struttura STRUCT_BUFCIR
Ritorno: byte quantita' di Bytes da prelevare
Descrizione: Valuta se almeno un carattere  presente in un buffer circolare di tipo STRUCT_BUFCIR
**********************************************************/
byte BufCirDataRdy(STRUCT_BUFCIR  *pd)
{
    return (pd->put != pd->get);
}

/*!**********************************************************
Funzione: void BufCirStrCopy(STRUCT_BUFCIR *pd, byte *pSrc, word len)
Argomenti: STRUCT_BUFCIR *pd puntatore alla tipo di struttura STRUCT_BUFCIR
		   byte *pSrc puntatore alla stringa da salvare nel buffer
		   word len lunghezza stringa da salvare nel buffer
Ritorno: nessuno
Descrizione: Carica una stringa in un buffer circolare di tipo STRUCT_BUFCIR
**********************************************************/
void BufCirStrCopy(STRUCT_BUFCIR *pd, byte *pSrc, word len)
{
byte i;
	for (i =0; i < len; i++)
	{
    	pd->buf[pd->put] = *pSrc++;
    	if (++pd->put >= pd->dim) pd->put = 0;
	}
}

/*!**********************************************************
Funzione: void BufCirPut(STRUCT_BUFCIR *pd, byte dat)
Argomenti: STRUCT_BUFCIR *pd puntatore alla tipo di struttura STRUCT_BUFCIR
		   byte dat dato da salvare nel buffer
Ritorno: nessuno
Descrizione: Carica un carattere in un buffer circolare di tipo STRUCT_BUFCIR
**********************************************************/
void BufCirPut(STRUCT_BUFCIR *pd, byte dat)
{
    pd->buf[pd->put] = dat;
    if (++pd->put >= pd->dim) pd->put = 0;
}

/*!**********************************************************
Funzione: void BufCirPut(STRUCT_BUFCIR *pd, byte dat)
Argomenti: STRUCT_BUFCIR *pd puntatore alla tipo di struttura STRUCT_BUFCIR
Ritorno: byte carattere prelevato dal buffer
Descrizione: Preleva un carattere da un buffer circolare di tipo STRUCT_BUFCIR
**********************************************************/
byte BufCirGet(STRUCT_BUFCIR *pd)
{
byte car;

    car = pd->buf[pd->get];
    if (++pd->get >= pd->dim) pd->get = 0;
    return car;
}

/*!**********************************************************
Funzione: void BufCirPut(STRUCT_BUFCIR *pd, byte dat)
Argomenti: STRUCT_BUFCIR *pd puntatore alla tipo di struttura STRUCT_BUFCIR
Ritorno: byte carattere prelevato dal buffer
Descrizione: Preleva un carattere da un buffer circolare di tipo STRUCT_BUFCIR
**********************************************************/
word BufCirChkIfLastOne(STRUCT_BUFCIR *pd)
{
	if ((pd->get+1) == pd->put)
		return TRUE;
	return FALSE;
}
