/***************************************************************************//**
* \file UART2_SPI_UART_PVT.h
* \version 4.0
*
* \brief
*  This private file provides constants and parameter values for the
*  SCB Component in SPI and UART modes.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2017, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_SPI_UART_PVT_UART2_H)
#define CY_SCB_SPI_UART_PVT_UART2_H

#include "UART2_SPI_UART.h"


/***************************************
*     Internal Global Vars
***************************************/

#if (UART2_INTERNAL_RX_SW_BUFFER_CONST)
    extern volatile uint32  UART2_rxBufferHead;
    extern volatile uint32  UART2_rxBufferTail;
    
    /**
    * \addtogroup group_globals
    * @{
    */
    
    /** Sets when internal software receive buffer overflow
     *  was occurred.
    */  
    extern volatile uint8   UART2_rxBufferOverflow;
    /** @} globals */
#endif /* (UART2_INTERNAL_RX_SW_BUFFER_CONST) */

#if (UART2_INTERNAL_TX_SW_BUFFER_CONST)
    extern volatile uint32  UART2_txBufferHead;
    extern volatile uint32  UART2_txBufferTail;
#endif /* (UART2_INTERNAL_TX_SW_BUFFER_CONST) */

#if (UART2_INTERNAL_RX_SW_BUFFER)
    extern volatile uint8 UART2_rxBufferInternal[UART2_INTERNAL_RX_BUFFER_SIZE];
#endif /* (UART2_INTERNAL_RX_SW_BUFFER) */

#if (UART2_INTERNAL_TX_SW_BUFFER)
    extern volatile uint8 UART2_txBufferInternal[UART2_TX_BUFFER_SIZE];
#endif /* (UART2_INTERNAL_TX_SW_BUFFER) */


/***************************************
*     Private Function Prototypes
***************************************/

void UART2_SpiPostEnable(void);
void UART2_SpiStop(void);

#if (UART2_SCB_MODE_SPI_CONST_CFG)
    void UART2_SpiInit(void);
#endif /* (UART2_SCB_MODE_SPI_CONST_CFG) */

#if (UART2_SPI_WAKE_ENABLE_CONST)
    void UART2_SpiSaveConfig(void);
    void UART2_SpiRestoreConfig(void);
#endif /* (UART2_SPI_WAKE_ENABLE_CONST) */

void UART2_UartPostEnable(void);
void UART2_UartStop(void);

#if (UART2_SCB_MODE_UART_CONST_CFG)
    void UART2_UartInit(void);
#endif /* (UART2_SCB_MODE_UART_CONST_CFG) */

#if (UART2_UART_WAKE_ENABLE_CONST)
    void UART2_UartSaveConfig(void);
    void UART2_UartRestoreConfig(void);
#endif /* (UART2_UART_WAKE_ENABLE_CONST) */


/***************************************
*         UART API Constants
***************************************/

/* UART RX and TX position to be used in UART2_SetPins() */
#define UART2_UART_RX_PIN_ENABLE    (UART2_UART_RX)
#define UART2_UART_TX_PIN_ENABLE    (UART2_UART_TX)

/* UART RTS and CTS position to be used in  UART2_SetPins() */
#define UART2_UART_RTS_PIN_ENABLE    (0x10u)
#define UART2_UART_CTS_PIN_ENABLE    (0x20u)


/***************************************
* The following code is DEPRECATED and
* must not be used.
***************************************/

/* Interrupt processing */
#define UART2_SpiUartEnableIntRx(intSourceMask)  UART2_SetRxInterruptMode(intSourceMask)
#define UART2_SpiUartEnableIntTx(intSourceMask)  UART2_SetTxInterruptMode(intSourceMask)
uint32  UART2_SpiUartDisableIntRx(void);
uint32  UART2_SpiUartDisableIntTx(void);


#endif /* (CY_SCB_SPI_UART_PVT_UART2_H) */


/* [] END OF FILE */
