
#define __UART2_H

#include <project.h>
#include <stdlib.h>
#include <stdio.h>
#include <typedef.h>
#include <common.h>
#include <bufcir.h>
#include <timer.h>
#include <rout.h>
#include <UART2.h>
#include <uart2Drv.h>
#include <main.h>



//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

//===============================================================================================
void ISR_UART(void)
//===============================================================================================
{
    /* Returns the status/identity of which enabled RX interrupt source caused interrupt event */
    uint32 source = UART_GetRxInterruptSource();

	/* Checks for "RX FIFO AND not empty" interrupt */
    if(0ul != (UART_INTR_RX_NOT_EMPTY & source))
    {
        /* Get the character from terminal */
        //read_character = UART_UartGetChar();

        /* Clear UART "RX FIFO not empty interrupt" */
        UART_ClearRxInterruptSource(UART_INTR_RX_NOT_EMPTY);

    }
    else
    {
        //error_uart = 1;
    }
    UART_ClearPendingInt();
}

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

extern void Uart2Init(void);

//===============================================================================================
void Uart2VarInit(void)
//===============================================================================================
{
	memset((char *)&uart2,0,sizeof(uart2));
}

//===============================================================================================
static char Uart2Busy(void)
//===============================================================================================
{
    return 1;
}

//===============================================================================================
void ISR_UART2(void)
//===============================================================================================
{
    uint8 chr;
    uint32 source = UART2_GetRxInterruptSource();

    /* Checks for "RX FIFO AND not empty" interrupt */
    if(0ul != (UART2_INTR_RX_NOT_EMPTY & source))
    {
#if 0
                        /* ...........................................disable the
                        * RX Not Empty interrupt source. The data elements are
                        * still being received into the RX FIFO until the RTS signal
                        * stops the transmitter. After the data element is read from the
                        * buffer, the RX Not Empty interrupt source is enabled to
                        * move the next data element in the software buffer.
                        */
                        UART2_INTR_RX_MASK_REG &= ~UART2_INTR_RX_NOT_EMPTY;
#endif

        // Rx carattere
        chr = UART2_UartGetChar();
        
        uart2.toutClearRxbuf_10mS = 10; // semplice modo per pulire Rx buffer su dati non voluti....

        if (!uart2.rxMsgRdy)
        {
            uart2.rxBuf[uart2.rxCtr++] = chr;

			if (chr == '+')
			{
                if (++uart2.escapeCtr >= 3)
                {
                    // clear rx buffer: Main() vede "uart2.escapeCtr"
            	    uart2.rxCtr=0;
            	    memset((char *)&uart2.rxBuf,0,sizeof(uart2.rxBuf));
                }
			}
			else
			{
				uart2.escapeCtr =0;

            	if (uart2.rxCtr < sizeof(uart2.rxBuf))
            	{
            	    if (chr == 13)  // CR
            	    {
            	        uart2.rxBuf[uart2.rxCtr] = 0; //EOS
            	        uart2.rxMsgRdy =1;
            	    }
            	}
            	else
            	{
            	    // overflow
            	    uart2.rxCtr=0;
            	    memset((char *)&uart2.rxBuf,0,sizeof(uart2.rxBuf));
            	}
			}
        }
        /* Clear UART "RX FIFO not empty interrupt" */
        UART2_ClearRxInterruptSource(UART2_INTR_RX_NOT_EMPTY);
    }
    else
    {
        source = UART2_GetTxInterruptSource();

        if (UART2_INTR_TX_EMPTY & source)
        {
            if (uart2.txCtr)
            {
                // Tx carattere
                UART2_UartPutChar(*uart2.txPtr++);
                --uart2.txCtr;
            }
            else
            {
                // Stop Irq Tx
                UART2_DISABLE_INTR_TX(UART2_INTR_TX_NOT_FULL);
            }
            /* Clear UART "RX FIFO not empty interrupt" */
            UART2_ClearTxInterruptSource(UART2_INTR_TX_EMPTY);
        }
    }

	/* Checks for "RX FIFO AND not empty" interrupt */
    UART2_ClearPendingInt();

}


//===============================================================================================
void Uart2SendString(char *p)
//===============================================================================================
{
    if (strlen(p) <= sizeof(uart2.txBuf))
    {
        //printf((const char *)p);
        strcpy((char *)&uart2.txBuf, p);
        uart2.txCtr =strlen(p);
        uart2.txPtr =(char *)&uart2.txBuf;
        // Start Irq Tx
        UART2_ENABLE_INTR_TX(UART2_INTR_TX_NOT_FULL);
    }
}

//===============================================================================================
char Uart2ReceiveString(char *p)
//===============================================================================================
{
    if (uart2.rxMsgRdy)
    {
        if (!strcmp((const char *)p, (const char *)&uart2.rxBuf))
        {
            uart2.rxMsgRdy =0;
            return 1;
        }
    }
    return 0;
}

